Learn R Programming

msig (version 1.0)

show_local_collection: Show collections of local MsigDB database

Description

Show collections of local MsigDB database

Usage

show_local_collection()

Arguments

Value

A dataframe contains 2 columns. The first column is the name of the collection. The second column is the number of frequencies it has.

Examples

Run this code
# NOT RUN {
show_local_collection()

# }

Run the code above in your browser using DataLab