Learn R Programming

msig (version 1.0)

show_local_contributor_org: Show contributor_orgs of local MsigDB database

Description

Show contributor_orgs of local MsigDB database

Usage

show_local_contributor_org()

Arguments

Value

A dataframe contains 2 columns. The first column is the name of the contributor_org. The second column is the number of frequencies it has.

Examples

Run this code
# NOT RUN {
show_local_contributor_org()

# }

Run the code above in your browser using DataLab