Learn R Programming

msig (version 1.0)

show_local_sub_collection: Show sub_collections of local MsigDB database

Description

Show sub_collections of local MsigDB database

Show sub_collections of local MsigDB database

Usage

show_local_sub_collection()

show_local_sub_collection()

Arguments

Value

A dataframe contains 2 columns. The first column is the name of the sub_collection. The second column is the number of frequencies it has.

A dataframe contains 2 columns. The first column is the name of the sub_collection. The second column is the number of frequencies it has.

Examples

Run this code
# NOT RUN {
show_local_sub_collection()

show_local_sub_collection()

# }

Run the code above in your browser using DataLab