powered by
Show collections of local MsigDB database
show_local_collection()
A dataframe contains 2 columns. The first column is the name of the collection. The second column is the number of frequencies it has.
# NOT RUN { show_local_collection() # }
Run the code above in your browser using DataLab