powered by
Show contributor_orgs of local MsigDB database
show_local_contributor_org()
A dataframe contains 2 columns. The first column is the name of the contributor_org. The second column is the number of frequencies it has.
# NOT RUN { show_local_contributor_org() # }
Run the code above in your browser using DataLab